# Section74SummaryResponse

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**permit_reference_number** | **str** |  | 
**section_74_reference_number** | **str** |  | 
**date_created** | **datetime** |  | 
**overrun_warning_reasons** | [**list[OverrunWarningReasonResponse]**](OverrunWarningReasonResponse.md) |  | 
**overrun_warning_reasons_string** | **list[str]** |  | 
**ha_status** | [**Section74HAStatusResponse**](Section74HAStatusResponse.md) |  | 
**ha_status_string** | **str** |  | 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

